@@ -71,24 +71,6 @@ class Source(SQLModel, table=True):
         arbitrary_types_allowed = True
 
 
-class FeedEntry(BaseModel):
-    title: str
-    summary: Optional[str]
-    published_at: datetime
-    url: HttpUrl = Field(alias="link")
-    authors: Optional[str] = Field(alias="author")
-    source_id: UUID
-
-
-class Feed(BaseModel):
-    title: str
-    subtitle: Optional[str]
-    entries: list[FeedEntry]
-    url: HttpUrl = Field(alias="link")
-    updated_at: datetime
-    source_id: UUID
-
-
 class Article(SQLModel, table=True):
     id: Optional[UUID] = Field(default_factory=uuid4, primary_key=True, index=True)
     url: HttpUrl = Field(nullable=False, sa_column=Column(unique=True))
